@@ -459,11 +459,16 @@ Rcpp::List cpp_move_swap_cases(Rcpp::List param, Rcpp::List data,
   Rcpp::IntegerVector local_cases;
 
   size_t N = static_cast<size_t>(data["N"]);
-
+  int N_int = data["N"];
+  
   double old_loglike = 0.0, new_loglike = 0.0, p_accept = 0.0;
 
+  // Shuffle indices to make equal cases equally likely
+  Rcpp::IntegerVector idx = Rcpp::seq(0, N-1);
+  idx = Rcpp::sample(idx, N_int, false);
 
-  for (size_t i = 0; i < N; i++) {
+  for (size_t j = 0; j < N; ++j) {
+    size_t i = (size_t)idx[j];
 
     // only non-NA ancestries are moved, if there is at least 1 choice
     if (alpha[i] != NA_INTEGER && sum(t_inf < t_inf[i]) > 0) {
