@@ -1,5 +1,5 @@
 context("Test non-exported functions")
-current_R_version <- gsub("R version ([0-9.]+) .+$", "\\1", R.version.string) 
+current_R_version <- gsub("R version ([0-9.]+) .+$", "\\1", R.version.string)
 
 ## test .choose_possible_alpha ##
 test_that("test: .choose_possible_alpha", {
@@ -41,7 +41,7 @@ test_that("Auxiliary functions for ancestries are working", {
   ## generate data
   alpha <- c(2, NA, 1, 3, 3, 1)
   t_inf <- c(2, 1, 3, 4, 4, 3)
-  data <- outbreaker_data(dates = t_inf+1)
+  data <- outbreaker_data(dates = t_inf+1, w_dens = rep(1, 100))
   config <- create_config(init_tree = alpha, init_t_inf = t_inf, data = data)
   config2 <- config
   config2$move_alpha <- c(rep(TRUE,4),FALSE, TRUE)
@@ -52,7 +52,7 @@ test_that("Auxiliary functions for ancestries are working", {
   expect_equal(can_move_alpha(param, config2), c(TRUE, FALSE, TRUE, TRUE, FALSE, TRUE))
 
   ## test ancestor selection
-  RNGversion("3.5.2")
+  suppressWarnings(RNGversion("3.5.2"))
   set.seed(1)
   to_move <- replicate(10, select_alpha_to_move(param,config))
   expect_equal(to_move, c(3,3,4,6,3,6,6,5,5,1))
@@ -120,7 +120,6 @@ test_that("Testing find_descendents", {
   expect_equal(cpp_find_descendents(c(1,NA,2,1), 1), c(1L, 4L))
   expect_equal(cpp_find_descendents(c(NA, 1,1,1,2,2,NA,1,1), 1),
                c(2L, 3L, 4L, 8L, 9L))
-  expect_equal(cpp_find_descendents(c(NA,1,NA,2), NA_integer_), integer(0))
 })
 
 
@@ -194,7 +193,8 @@ test_that("Testing cpp_get_n_mutations", {
   ## sequences in natural order
 
   data <- outbreaker_data(dates = fake_outbreak$onset,
-                          dna = fake_outbreak$dna)
+                          dna = fake_outbreak$dna,
+                          w_dens = rep(1, 100))
   D <- data$D
 
   expect_equal(cpp_get_n_mutations(data, 1, 1), 0L)
@@ -208,7 +208,8 @@ test_that("Testing cpp_get_n_mutations", {
   rownames(dna.rev) <- as.character(30:1)
 
   data.rev <- outbreaker_data(dates = fake_outbreak$onset,
-                              dna = dna.rev)
+                              dna = dna.rev,
+                              w_dens = rep(1, 100))
   D.rev <- data.rev$D
 
   expect_equal(rownames(D.rev), rownames(dna.rev))
@@ -221,7 +222,8 @@ test_that("Testing cpp_get_n_mutations", {
   rownames(dna.miss) <- c("3", "4", "11")
 
   data.miss <- outbreaker_data(dates = fake_outbreak$onset,
-                               dna = dna.miss)
+                               dna = dna.miss,
+                               w_dens = rep(1, 100))
   D.miss <- data.miss$D
 
   expect_equal(rownames(D.miss), rownames(dna.miss))
@@ -248,7 +250,7 @@ test_that("Look for sequenced ancestors", {
 
   ## make inputs
   onset <- as.integer(c(0, 1, 2, 3, 2, 1, 2, 3))
-  data <- outbreaker_data(onset = onset)
+  data <- outbreaker_data(dates = onset, w_dens = rep(1, 100))
 
   has_dna <- as.logical(c(0, 1, 0, 1, 1, 0, 0, 1))
   data$has_dna <- has_dna
